# -*- coding: utf-8 -*-

VERSION = (0, 1, 4, "")
__version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
__author__ = "Arezqui Belaid"
__contact__ = "areski@gmail.com"
__homepage__ = "http://www.areski.net"
__docformat__ = "restructuredtext"
